# ssllabs Documentation

The documentation is autogenerated using [Sphinx](https://www.sphinx-doc.org).

## System requirements

Defining the system requirements with exact versions typically is difficult. But there is a tested environment:

* Linux
* Python 3.7.9
* Sphinx 3.5.2
* m2r2 0.2.7
* pydata_sphinx_theme 0.5.1

## Building the docs

First you need to take care of the requirements.

```bash
pip install -e .[docs]
```

Then just use the make file.

```bash
cd docs
make html
```

You will find the build documentation in ```docs/_build/html``` afterwards.
